@@ -1,6 +1,6 @@
 import enum
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from pydantic import BaseModel, Extra, Field, validator
 
@@ -41,6 +41,14 @@ class LocationSet(str, enum.Enum):
     SCHEMATIC = "schematic_location"
 
 
+class LocationExtent(BaseModel):
+    """Mapping of dimensions to range, e.g. {"x": [-10, 10]}"""
+
+    x: Optional[Tuple[float, float]] = None
+    y: Optional[Tuple[float, float]] = None
+    z: Optional[Tuple[float, float]] = None
+
+
 class BaseLink(BaseElement):
     source_uid: str = Field(..., description="UID of source node")
     target_uid: str = Field(..., description="UID of target node")
